@@ -1,11 +1,12 @@
 import asyncio
 import random
 import struct
+import enum
 
 from .errors import *
 
 
-class MessageType:
+class MessageType(enum.IntEnum):
     LOGIN = 3
     COMMAND = 2
     RESPONSE = 0
@@ -71,9 +72,21 @@ class Client:
         in_len = struct.unpack("<i", (await self._reader.read(4)))[0]
 
         # read rest of packet data
-        in_data = await self._reader.read(in_len)
+        in_arr = []
+        in_tlen = 0
 
-        if not in_data.endswith(b"\x00\x00"):
+        while in_tlen < in_len:
+            in_tmp = await self._reader.read(in_len - in_tlen)
+
+            if not in_tmp:
+                break
+
+            in_tlen += len(in_tmp)
+            in_arr.append(in_tmp)
+
+        in_data = b"".join(in_arr)
+
+        if len(in_data) != in_len or not in_data.endswith(b"\x00\x00"):
             raise ValueError("Invalid data received from server.")
 
         # decode the incoming request id and packet type
